%SQLITE provides the interfaces to access SQLite databases, along with sqlite_mex.
%
%   db = sqlite;
%   db.version
%   db.connect('test.db');
%   db.query('CREATE TABLE Test (Subject TEXT, Score INTEGER);');
%   db.query('INSERT INTO Test (Subject,Score) VALUES (''English'',50);');
%   db.query('INSERT INTO Test (Subject,Score) VALUES (?,?);','Math',90);
%   db.query('UPDATE Test SET Score=80 WHERE Subject=''English'';');
%   table = db.query('SELECT * from Test;');
%   db.query('DELETE FROM Test WHERE Score<90;');
%
%   cell_mat = { uint8('A byte stream in a cell matrix is considered a blob.') };
%   db.query('CREATE TABLE BinaryLargeOBject (Object Blob);');
%   db.query('INSERT INTO BinaryLargeOBject (Object) VALUES (?);',cell_mat);
%
%   clear db;  % This also disconnect DB. 'db.delete' does the same.
%
%   Jun 17, 2015        Written by Jaewon Hwang (jaewon.hwang@gmail.com)

classdef sqlite < handle
    properties (Access = protected)
        db;
    end
    methods
        function obj = sqlite()
            obj.db = sqlite_mex(1);
        end
        function delete(obj)
            sqlite_mex(2, obj.db);
        end
        function connect(obj, dbname)
            sqlite_mex(3, obj.db, dbname);
        end
        function disconnect(obj)
            sqlite_mex(4, obj.db);
        end
        function table = query(obj, str, varargin)
            table = sqlite_mex(5, obj.db, str, varargin);
        end
    end
    methods (Static) 
        function ver = version()
            ver = sqlite_mex(0);
        end
    end
end